@@ -18,6 +18,12 @@
 
 if (getRversion() >= "2.15.1")  {
   utils::globalVariables(
-    c("x", "y", "lab", "intervals", "csgp")
+    c("x", "y", "lab", "intervals", "csgp",
+      "t50_Coolbear", "t50_Farooq", "GermRateRecip_Coolbear",
+      "GermRateRecip_Farooq", "GermSpeed_Count", "GermSpeed_Percent",
+      "GermSpeedAccumulated_Count", "GermSpeedAccumulated_Percent",
+      "GermSpeedCorrected_Normal", "GermSpeedCorrected_Accumulated",
+      "TimsonsIndex_Labouriau", "TimsonsIndex_KhanUngar", "GermValue_Czabator",
+      "GermValue_DP", "GermValue_Czabator_mod", "GermValue_DP_mod")
   )
 }
